@@ -11,8 +11,8 @@ use File::Path qw/mkpath/;
 use Log::Log4perl qw(:easy);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
 
-# ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '1.31'; # VERSION
+# ABSTRACT: (Deprecated) Yet Another RESTful-Archive Service
+our $VERSION = '1.32'; # VERSION
 
 
 has secret => rand;
@@ -197,11 +197,11 @@ __END__
 
 =head1 NAME
 
-Yars - Yet Another RESTful-Archive Service
+Yars - (Deprecated) Yet Another RESTful-Archive Service
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SYNOPSIS
 
@@ -236,6 +236,13 @@ Download a file
 
 =head1 DESCRIPTION
 
+B<NOTE>: Development for this tool is winding down, and L<Yars> is
+deprecated.  Please contact me ASAP if you depend on this tool.
+Please see and/or comment on
+L<https://github.com/clustericious/Yars/issues/31> for details.
+Yars as a distribution may be removed from CPAN, but not before
+December 31, 2018.
+
 Yars is a simple RESTful server for data storage.
 
 Properly configured it provides consistent WRITE availability, and 
